pub struct IntoCp437Error { /* private fields */ }Expand description
A possible error value when converting a String into a cp437 byte vector.
This type is the error type for the into_cp437()
function on IntoCp437. It is designed in such a way to carefully avoid reallocations:
the into_string() function will give back the String that was used
in the conversion attempt.
The Cp437Error type represents an error that may
occur when converting a &str to a sequence of u8s. In this sense, it’s
an analogue to IntoCp437Error, and you can get one from a IntoCp437Error
through the cp437_error() function.
Examples
// some unrepresentable chracters, in a String
let word = "Eżektor".to_string();
let value = word.into_cp437(&CP437_CONTROL);
assert!(value.is_err());
assert_eq!(value.unwrap_err().into_string(), "Eżektor".to_string());Implementations
Sourceimpl IntoCp437Error
impl IntoCp437Error
Sourcepub fn as_str(&self) -> &str
pub fn as_str(&self) -> &str
Returns a &str that was attempted to convert to cp437.
Examples
// some unrepresentable chracters, in a String
let word = "Eżektor".to_string();
let value = word.into_cp437(&CP437_CONTROL);
assert_eq!(value.unwrap_err().as_str(), "Eżektor");Sourcepub fn into_string(self) -> String
pub fn into_string(self) -> String
Returns the String that was attempted to convert to cp437.
This function is carefully constructed to avoid allocation. It will consume the error, moving out the string, so that a copy of the string does not need to be made.
Examples
// some unrepresentable chracters, in a String
let word = "Eżektor".to_string();
let value = word.into_cp437(&CP437_CONTROL);
assert_eq!(value.unwrap_err().into_string(), "Eżektor".to_string());Sourcepub fn cp437_error(&self) -> Cp437Error
pub fn cp437_error(&self) -> Cp437Error
Fetch a Cp437Error to get more details about the conversion failure.
The Cp437Error type represents an error that may
occur when converting a &str to a sequence of u8s. In this sense, it’s
an analogue to IntoCp437Error. See its documentation for more details
on using it.
Examples
// some unrepresentable chracters, in a String
let word = "Eżektor".to_string();
let error = word.into_cp437(&CP437_CONTROL).unwrap_err().cp437_error();
// the first character is unrepresentable here
assert_eq!(error.representable_up_to, 1);Trait Implementations
Sourceimpl Clone for IntoCp437Error
impl Clone for IntoCp437Error
Sourcefn clone(&self) -> IntoCp437Error
fn clone(&self) -> IntoCp437Error
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for IntoCp437Error
impl Debug for IntoCp437Error
impl Eq for IntoCp437Error
Sourceimpl Hash for IntoCp437Error
impl Hash for IntoCp437Error
Sourceimpl Ord for IntoCp437Error
impl Ord for IntoCp437Error
Sourcefn cmp(&self, other: &IntoCp437Error) -> Ordering
fn cmp(&self, other: &IntoCp437Error) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialEq for IntoCp437Error
impl PartialEq for IntoCp437Error
Sourcefn eq(&self, other: &IntoCp437Error) -> bool
fn eq(&self, other: &IntoCp437Error) -> bool
self and other values to be equal, and is used by ==.